The unified diff between revisions [24fb0b25..] and [8032bf83..] is displayed below. It can also be downloaded as a raw diff.

This diff has been restricted to the following files: 'tests/checkout_validates_target_directory/__driver__.lua'

#
#
# patch "tests/checkout_validates_target_directory/__driver__.lua"
#  from [bdfd6c99a8ebc76e7959ef79868a6373cfe30f54]
#    to [14039447ff443f0bd7a61a0e25cd76bf995be046]
#
============================================================
--- tests/checkout_validates_target_directory/__driver__.lua	bdfd6c99a8ebc76e7959ef79868a6373cfe30f54
+++ tests/checkout_validates_target_directory/__driver__.lua	14039447ff443f0bd7a61a0e25cd76bf995be046
@@ -14,9 +14,10 @@ if existsonpath("chmod") and existsonpat

 if existsonpath("chmod") and existsonpath("test") then
   -- Skip this part if run as root (hi Gentoo!)
   -- Also skip if on Windows, since these permissions are not enforced there
   if check({"test", "-O", "/"}, false, false, false) == 0 or
-     ostype == "Windows"
+     ostype == "Windows" or
+     string.find (ostype, "CYGWIN")
   then
     partial_skip = true
   else
@@ -14,9 +14,10 @@ if existsonpath("chmod") and existsonpat
 if existsonpath("chmod") and existsonpath("test") then
   -- Skip this part if run as root (hi Gentoo!)
-  -- Also skip if on Windows, since these permissions are not enforced there
+  -- Also skip if on Windows or Cygwin, since these permissions are not enforced there
   if check({"test", "-O", "/"}, false, false, false) == 0 or